:py:mod:`icclim._core`
======================

.. py:module:: icclim._core

.. autoapi-nested-parse::

   icclim's internal core module.

   The structure of this module may change without warnings.
   Avoid importing from this module directly.



Subpackages
-----------
.. toctree::
   :titlesonly:
   :maxdepth: 3

   model/index.rst


Submodules
----------
.. toctree::
   :titlesonly:
   :maxdepth: 1

   climate_variable/index.rst
   constants/index.rst
   frequency/index.rst
   input_parsing/index.rst
   utils/index.rst
